@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.097-9-g6acdf1e
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.098-14-g6185f78
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.098';
+our $VERSION = '0.099';
 
 use Moose;
 with
@@ -77,12 +77,12 @@ has changes_version_columns => (
 # configs are applied when plugins match ->isa($key) or ->does($key)
 my %extra_args = (
     'Dist::Zilla::Plugin::MakeMaker' => { 'eumm_version' => '0' },
-    'Dist::Zilla::Plugin::ModuleBuildTiny' => { ':version' => '0.009', version_method => 'conservative' },
+    'Dist::Zilla::Plugin::ModuleBuildTiny' => { ':version' => '0.012', version_method => 'conservative', static => 'auto' },
     'Dist::Zilla::Plugin::MakeMaker::Fallback' => { ':version' => '0.012' },
     # default_jobs is no-op until Dist::Zilla 5.014
     'Dist::Zilla::Role::TestRunner' => { default_jobs => 9 },
     'Dist::Zilla::Plugin::ModuleBuild' => { mb_version => '0.28' },
-    'Dist::Zilla::Plugin::ModuleBuildTiny::Fallback' => { ':version' => '0.006' },
+    'Dist::Zilla::Plugin::ModuleBuildTiny::Fallback' => { ':version' => '0.018', version_method => 'conservative', static => 'auto' },
 );
 
 # plugins that use the network when they run
@@ -161,8 +161,14 @@ sub configure
 
     my @plugins = (
         # VersionProvider
-        [ 'RewriteVersion::Transitional' => { ':version' => '0.004', global => 1, fallback_version_provider => 'Git::NextVersion', version_regexp => '^v([\d._]+)(-TRIAL)?$',
-                (map { (my $key = $_) =~ s/Git::NextVersion\.//; $key => $self->payload->{$_} } grep { /^Git::NextVersion\./ } keys %{ $self->payload }) } ],
+        [ 'RewriteVersion::Transitional' => {
+                ':version' => '0.004',
+                global => 1,
+                add_tarball_name => 0,
+                fallback_version_provider => 'Git::NextVersion',
+                version_regexp => '^v([\d._]+)(-TRIAL)?$',
+                (map { (my $key = $_) =~ s/Git::NextVersion\.//; $key => $self->payload->{$_} } grep { /^Git::NextVersion\./ } keys %{ $self->payload })
+            } ],
 
         # BeforeBuild
         # [ 'EnsurePrereqsInstalled' ], # FIXME: use options to make this less annoying!
@@ -200,9 +206,9 @@ sub configure
         'PodCoverageTests',
         [ 'Test::PodSpelling'   => { ':version' => '2.006001' } ],
         #[Test::Pod::LinkCheck]     many outstanding bugs
-        'Test::Pod::No404s',
+        [ 'Test::Pod::No404s'   => { ':version' => '1.002' } ],
         [ 'Test::Kwalitee'      => { ':version' => '2.06', filename => 'xt/author/kwalitee.t' } ],
-        'MojibakeTests',
+        [ 'MojibakeTests'       => { ':version' => '0.8' } ],
         [ 'Test::ReportPrereqs' => { ':version' => '0.019', verify_prereqs => 1,
             exists $removed{PodCoverageTests} ? () : ( include => [ 'Pod::Coverage' ] ),
           } ],
@@ -224,7 +230,7 @@ sub configure
         [ 'ReadmeAnyFromPod'    => { ':version' => '0.142180', type => 'pod', location => 'root', phase => 'release' } ],
 
         # MetaData
-        $self->server eq 'github' ? [ 'GithubMeta' => { homepage => 0, issues => 0 } ] : (),
+        $self->server eq 'github' ? [ 'GithubMeta' => { ':version' => '0.54', homepage => 0, issues => 0 } ] : (),
         [ 'AutoMetaResources'   => { 'bugtracker.rt' => 1,
               $self->server eq 'gitmo' ? ( 'repository.gitmo' => 1 )
             : $self->server eq 'p5sagit' ? ( 'repository.p5sagit' => 1 )
@@ -238,6 +244,7 @@ sub configure
         'MetaConfig',
         [ 'Keywords'            => { ':version' => '0.004' } ],
         [ 'Git::Contributors'   => { ':version' => '0.004', order_by => 'commits' } ],
+        # [StaticInstall]
 
         # Register Prereqs
         # (MakeMaker or other installer)
@@ -256,6 +263,12 @@ sub configure
         # Install Tool (some are also Test Runners)
         $self->installer,
 
+        [ 'StaticInstall' => {
+                ':version' => '0.005', mode => 'auto',
+                dry_run => ($self->payload->{'Authority.authority'} // 'cpan:ETHER') eq 'cpan:ETHER'
+                    || ($self->payload->{'StaticInstall.mode'} // '') eq 'off' ? 0 : 1,
+            } ],
+
         # Test Runners (load after installers to avoid a rebuild)
         [ 'RunExtraTests'       => { ':version' => '0.024' } ],
 
@@ -340,10 +353,15 @@ sub configure
         push @$plugin_spec, {} if not ref $plugin_spec->[-1];
         my $payload = $plugin_spec->[-1];
 
-        if (my @keys = grep { $plugin->isa($_) or $plugin->does($_) } keys %extra_args)
+        if (my @modules_for_extra_configs = grep { $plugin->isa($_) or $plugin->does($_) } keys %extra_args)
         {
-            # combine all the relevant configs together
-            my %configs = map { %{ $extra_args{$_} } } @keys;
+            # combine all the relevant configs together, but don't take
+            # :version unless it matches the package exactly
+            my %configs = map { %{ $extra_args{$_} } } @modules_for_extra_configs;
+            delete $configs{':version'};
+
+            $configs{':version'} = $extra_args{$plugin}{':version'}
+                if exists $extra_args{$plugin} and exists $extra_args{$plugin}{':version'};
 
             # and add to the payload of this plugin
             @{$payload}{keys %configs} = values %configs;
@@ -375,7 +393,9 @@ sub _pause_config
     my $file = path($ENV{HOME} // 'oops', '.pause');
     return if not -e $file;
 
-    my ($username, $password) = map { my (undef, $val) = split ' ', $_; $val } $file->lines;
+    my ($username, $password) = map {
+        my (undef, $val) = split ' ', $_; $val  # awk-style whitespace splitting
+    } $file->lines;
 }
 
 sub _uniq { keys %{ +{ map { $_ => undef } @_ } } }
@@ -394,7 +414,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.098
+version 0.099
 
 =head1 SYNOPSIS
 
@@ -413,6 +433,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [RewriteVersion::Transitional]
     :version = 0.004
     global = 1
+    add_tarball_name = 0
     fallback_version_provider = Git::NextVersion
     version_regexp = ^v([\d._]+)(-TRIAL)?$
 
@@ -500,10 +521,12 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Test::PodSpelling]
     ;[Test::Pod::LinkCheck]     many outstanding bugs
     [Test::Pod::No404s]
+    :version = 1.002
     [Test::Kwalitee]
     :version = 2.06
     filename = xt/author/kwalitee.t
     [MojibakeTests]
+    :version = 0.8
     [Test::ReportPrereqs]
     :version = 0.019
     verify_prereqs = 1
@@ -533,6 +556,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
 
     ;;; MetaData
     [GithubMeta]    ; (if server = 'github' or omitted)
+    :version = 0.54
     homepage = 0
     issues = 0
 
@@ -572,6 +596,7 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     [Git::Contributors]
     :version = 0.004
     order_by = commits
+    ;[StaticInstall]   ; below
 
 
     ;;; Register Prereqs
@@ -595,6 +620,11 @@ following F<dist.ini> (following the preamble), minus some optimizations:
     ;;; Install Tool
     <specified installer(s)>
 
+    [StaticInstall]
+    :version = 0.005
+    mode = auto
+    dry_run = 1  ; only if authority is not ETHER
+
 
     ;;; Test Runner
     ; <specified installer(s)>
